beamtools.apply_complex_beam_spanners_to_measures_in_expr
=========================================================

.. autofunction:: abjad.tools.beamtools.apply_complex_beam_spanners_to_measures_in_expr.apply_complex_beam_spanners_to_measures_in_expr
   :noindex:
